@@ -1,5 +1,5 @@
 from sinta_scraper.author_retriever import author, authors
 from sinta_scraper.dept_retriever import dept_authors, depts_authors
-from sinta_scraper.document_retriever import author_scholar_docs
+from sinta_scraper.scholar_documents_retriever import author_scholar_docs
 from sinta_scraper.ipr_retriever import author_ipr
 from sinta_scraper.research_retriever import author_researches
